@@ -36,8 +36,8 @@ config = dict(
         # name of it's calling module to determine which endpoint definition
         # to use.  This can be overridden by explicitly providing the name in
         # the initial call to fedmsg.init(...).
-        "bodhi.%s" % hostname: ["tcp://127.0.0.1:3001"],
-        "fas.%s" % hostname: ["tcp://127.0.0.1:3002"],
-        "fedoratagger.%s" % hostname: ["tcp://127.0.0.1:3003"],
+        #"bodhi.%s" % hostname: ["tcp://127.0.0.1:3001"],
+        #"fas.%s" % hostname: ["tcp://127.0.0.1:3002"],
+        #"fedoratagger.%s" % hostname: ["tcp://127.0.0.1:3003"],
     },
 )
